=== modified file 'lib/canonical/launchpad/browser/launchpad.py'
--- lib/canonical/launchpad/browser/launchpad.py	2007-10-18 21:24:33 +0000
+++ lib/canonical/launchpad/browser/launchpad.py	2007-10-23 16:26:47 +0000
@@ -483,18 +483,23 @@
         if name == 'bazaar' and IXMLRPCRequest.providedBy(self.request):
             return getUtility(IBazaarApplication)
 
-        try:
-            # account for common typing mistakes
-            if canonical_name(name) != name:
-                if self.request.method == 'POST':
-                    raise POSTToNonCanonicalURL
-                return self.redirectSubTree(
-                    canonical_url(self.context) + canonical_name(name),
-                    status=301)
-            else:
-                return getUtility(IPillarNameSet)[name]
-        except NotFoundError:
-            return None
+        # account for common typing mistakes
+        if canonical_name(name) != name:
+            if self.request.method == 'POST':
+                raise POSTToNonCanonicalURL
+            return self.redirectSubTree(
+                canonical_url(self.context) + canonical_name(name),
+                status=301)
+
+        admins = getUtility(ILaunchpadCelebrities).admin
+        user = getUtility(ILaunchBag).user
+        ignore_inactive = True
+        if user and user.inTeam(admins):
+            # Admins should be able to access deactivated projects too
+            ignore_inactive = False
+        pillar = getUtility(IPillarNameSet).getByName(
+            name, ignore_inactive=ignore_inactive)
+        return pillar
 
     def _getBetaRedirectionView(self):
         # If the inhibit_beta_redirect cookie is set, don't redirect:

=== added directory 'lib/canonical/launchpad/pagetests/pillar'
=== added file 'lib/canonical/launchpad/pagetests/pillar/xx-pillar-deactivation.txt'
--- lib/canonical/launchpad/pagetests/pillar/xx-pillar-deactivation.txt	1970-01-01 00:00:00 +0000
+++ lib/canonical/launchpad/pagetests/pillar/xx-pillar-deactivation.txt	2007-10-23 16:26:47 +0000
@@ -0,0 +1,84 @@
+= Pillar deactivation and reactivation =
+
+This test demonstrates what happens when you deactivate and reactivate
+pillars (Projects, Project Groups and Distributions).
+
+XXX: Distributions can't yet be marked inactive, so this test won't
+cover that part of the change. See bug #156263 for more details.
+    -- kiko, 2008-10-23
+
+    >>> def toggleProject(name):
+    ...     admin_browser.open('http://launchpad.dev/%s' % name)
+    ...     admin_browser.getLink(url='+review').click()
+    ...     state = admin_browser.getControl('Active').selected
+    ...     admin_browser.getControl('Active').selected = (not state)
+    ...     admin_browser.getControl('Change').click()
+
+We start off with active and visible projects:
+
+    >>> anon_browser.open('http://launchpad.dev/projects/+index?text=firefox')
+    >>> anon_browser.getLink(url='/firefox').click()
+    >>> anon_browser.title
+    'Mozilla Firefox in Launchpad'
+
+    >>> anon_browser.open('http://launchpad.dev/projects/+index?text=mozilla')
+    >>> anon_browser.getLink(url='/mozilla').click()
+    >>> anon_browser.title
+    'The Mozilla Project in Launchpad'
+
+We then choose to disable them via each project's +review:
+
+    >>> toggleProject('firefox')
+    >>> toggleProject('mozilla')
+
+The projects are now no longer publically visible:
+
+    >>> anon_browser.open('http://launchpad.dev/projects/+index?text=mozilla')
+    >>> anon_browser.getLink(url='/firefox')
+    Traceback (most recent call last):
+    ...
+    LinkNotFoundError
+    >>> anon_browser.getLink(url='/mozilla')
+    Traceback (most recent call last):
+    ...
+    LinkNotFoundError
+
+    >>> anon_browser.open('http://launchpad.dev/firefox')
+    Traceback (most recent call last):
+    ...
+    NotFound:...
+
+    >>> anon_browser.open('http://launchpad.dev/mozilla')
+    Traceback (most recent call last):
+    ...
+    NotFound:...
+
+But an administrator can still see them if he traverses directly, and
+he'll see an informative message. He can then reactivate them..
+
+    >>> admin_browser.open('http://launchpad.dev/firefox')
+    >>> print find_tag_by_id(admin_browser.contents, 'project-inactive').renderContents()
+     This project is currently inactive...
+    >>> toggleProject('firefox')
+
+    >>> admin_browser.open('http://launchpad.dev/mozilla')
+    >>> print find_tag_by_id(admin_browser.contents, 'project-inactive').renderContents()
+     This project is currently inactive...
+    >>> toggleProject('mozilla')
+
+And they are back to normal:
+
+    >>> anon_browser.open('http://launchpad.dev/projects/+index?text=firefox')
+    >>> anon_browser.getLink(url='/firefox').click()
+    >>> anon_browser.title
+    'Mozilla Firefox in Launchpad'
+    >>> print find_tag_by_id(admin_browser.contents, 'project-inactive')
+    None
+
+    >>> anon_browser.open('http://launchpad.dev/projects/+index?text=mozilla')
+    >>> anon_browser.getLink(url='/mozilla').click()
+    >>> anon_browser.title
+    'The Mozilla Project in Launchpad'
+    >>> print find_tag_by_id(admin_browser.contents, 'project-inactive')
+    None
+

=== renamed file 'lib/canonical/launchpad/pagetests/standalone/xx-pillar-sprints.txt' => 'lib/canonical/launchpad/pagetests/pillar/xx-pillar-sprints.txt'
=== modified file 'lib/canonical/launchpad/templates/product-index.pt'
--- lib/canonical/launchpad/templates/product-index.pt	2007-10-22 23:48:35 +0000
+++ lib/canonical/launchpad/templates/product-index.pt	2007-10-23 16:26:47 +0000
@@ -7,6 +7,10 @@
 
 <div metal:fill-slot="main">
 
+  <p id="project-inactive" tal:condition="not: context/active" class="warning message"> 
+    This project is currently inactive <a href="+review">(change this)</a>
+  </p>
+
   <span tal:replace="structure context/image:mugshot" />
   <h1 tal:content="context/title">Name of project</h1>
 

=== modified file 'lib/canonical/launchpad/templates/project-index.pt'
--- lib/canonical/launchpad/templates/project-index.pt	2007-09-19 15:15:00 +0000
+++ lib/canonical/launchpad/templates/project-index.pt	2007-10-23 16:26:47 +0000
@@ -8,6 +8,10 @@
 
     <div metal:fill-slot="main">
 
+    <p id="project-inactive" tal:condition="not: context/active" class="warning message"> 
+      This project is currently inactive <a href="+review">(change this)</a>
+    </p>
+
     <tal:block condition="view/required:launchpad.Edit">
       <p tal:condition="not: context/products" class="warning message"> 
         There are no projects registered for

